aboutsummaryrefslogtreecommitdiffstats
path: root/ui
diff options
context:
space:
mode:
Diffstat (limited to 'ui')
-rw-r--r--ui/qt/main.cpp9
1 files changed, 8 insertions, 1 deletions
diff --git a/ui/qt/main.cpp b/ui/qt/main.cpp
index abb3a728e4..a834dcaf51 100644
--- a/ui/qt/main.cpp
+++ b/ui/qt/main.cpp
@@ -419,8 +419,15 @@ int main(int argc, char *qt_argv[])
CocoaBridge::cleanOSGeneratedMenuItems();
#endif
- /* Set the C-language locale to the native environment. */
+ /*
+ * Set the C-language locale to the native environment and set the
+ * code page to UTF-8 on Windows.
+ */
+#ifdef _WIN32
+ setlocale(LC_ALL, ".UTF-8");
+#else
setlocale(LC_ALL, "");
+#endif
#ifdef _WIN32
//